Documentation
¶
Index ¶
- func DecryptEntry(identitiesPath, passwordStore, name string) (string, error)
- func DecryptIdentities(identitiesPath string) (string, error)
- func EntryFile(passwordStore, name string) (string, error)
- func ParseIdentities(identityData string) ([]age.Identity, error)
- func ParseRecipients(contents string) ([]age.Recipient, error)
- func SaveEntry(recipientsPath, passwordStore, name, password string) error
- func WrapDecrypt(r io.Reader, identities ...age.Identity) (io.Reader, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DecryptEntry ¶
DecryptEntry decrypts a password entry from the store using identities from the identities file.
func DecryptIdentities ¶
DecryptIdentities decrypts the identities file using a password provided by the user.
func EntryFile ¶
EntryFile constructs the full file path for a given entry name in the store. It also checks the entry name for invalid characters and ensures the path is within the store.
func ParseIdentities ¶ added in v0.15.0
ParseIdentities parses a string containing age identities and/or SSH private keys. It supports both native age X25519 identities and PEM-encoded SSH private keys.
func ParseRecipients ¶
ParseRecipients parses the entire text of an recipients file, supporting both X25519 and SSH public key formats.
Types ¶
This section is empty.